==> pegasus-merchandise-api-2.6.8-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpCommissionProdWhiteCond.java <==
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.util.Date;
import java.util.List;

/**
 * Created by gensheng.ye on 2020/2/10.
 */
public class OpCommissionProdWhiteCond extends BaseQueryCond {

    private String productCode;
    private String skuCode;
    private Integer status;
    private Date validStartTime;
    private Date validEndTime;
    private Integer commissionRate;
    private List<String> productCodes;
    private boolean isRequireSkuCodeName;



    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Date getValidStartTime() {
        return validStartTime;
    }

    public void setValidStartTime(Date validStartTime) {
        this.validStartTime = validStartTime;
    }

    public Date getValidEndTime() {
        return validEndTime;
    }

    public void setValidEndTime(Date validEndTime) {
        this.validEndTime = validEndTime;
    }

    public Integer getCommissionRate() {
        return commissionRate;
    }

    public void setCommissionRate(Integer commissionRate) {
        this.commissionRate = commissionRate;
    }

    public List<String> getProductCodes() {
        return productCodes;
    }

    public void setProductCodes(List<String> productCodes) {
        this.productCodes = productCodes;
    }

    public boolean isRequireSkuCodeName() {
        return isRequireSkuCodeName;
    }

    public void setRequireSkuCodeName(boolean requireSkuCodeName) {
        isRequireSkuCodeName = requireSkuCodeName;
    }


}

==> pegasus-merchandise-api-4.0.22-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpCommissionProdWhiteCond.java <==
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.util.Date;
import java.util.List;

/**
 * Created by gensheng.ye on 2020/2/10.
 */
public class OpCommissionProdWhiteCond extends BaseQueryCond {

    private String productCode;
    private String skuCode;
    private Integer status;
    private Date validStartTime;
    private Date validEndTime;
    private Integer commissionRate;
    private List<String> productCodes;
    private boolean isRequireSkuCodeName;



    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Date getValidStartTime() {
        return validStartTime;
    }

    public void setValidStartTime(Date validStartTime) {
        this.validStartTime = validStartTime;
    }

    public Date getValidEndTime() {
        return validEndTime;
    }

    public void setValidEndTime(Date validEndTime) {
        this.validEndTime = validEndTime;
    }

    public Integer getCommissionRate() {
        return commissionRate;
    }

    public void setCommissionRate(Integer commissionRate) {
        this.commissionRate = commissionRate;
    }

    public List<String> getProductCodes() {
        return productCodes;
    }

    public void setProductCodes(List<String> productCodes) {
        this.productCodes = productCodes;
    }

    public boolean isRequireSkuCodeName() {
        return isRequireSkuCodeName;
    }

    public void setRequireSkuCodeName(boolean requireSkuCodeName) {
        isRequireSkuCodeName = requireSkuCodeName;
    }


}
